#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Tests for `play_mqtt` package."""

import mock


def test_provider():
    from play_mqtt import providers
    provider = providers.MQTTProvider(None)
    assert provider.engine is None
    assert provider.command_publish


def test_provider_command():
    from play_mqtt import providers
    with mock.patch('play_mqtt.providers.mqtt') as mock_mqtt:
        provider = providers.MQTTProvider(None)
        assert mock_mqtt.Client.assert_called_with() is None
        assert provider.mqttc is mock_mqtt.Client.return_value

        command = {
            'type': 'publish',
            'provider': 'mqtt',
            'comment': 'a comment',
            'host': 'host',
            'port': 10,
            'endpoint': 'some/endpoint',
            'payload': '{"foo": "bar"}'
        }
        provider.command_publish(command)

        assert provider.mqttc.connect.assert_called_with(
            command['host'], port=int(command['port'])) is None
        assert provider.mqttc.loop_start.assert_called_once_with() is None
        assert provider.mqttc.loop_stop.assert_called_once_with(
            force=False) is None
        assert provider.mqttc.publish.assert_called_once_with(
            command['endpoint'], command['payload']) is None



import paho.mqtt.client as mqtt
from pytest_play.providers import BaseProvider


class MQTTProvider(BaseProvider):
    """ MQTT provider """

    def __init__(self, engine):
        super(MQTTProvider, self).__init__(engine)
        self.mqttc = mqtt.Client()

    def command_publish(self, command, **kwargs):
        """ Publish a MQTT message """
        self.mqttc.connect(
            command['host'],
            port=int(command['port']))

        self.mqttc.loop_start()

        try:
            self.mqttc.publish(
                command['endpoint'],
                command['payload'])
        finally:
            self.mqttc.loop_stop(force=False)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('CHANGES.rst') as history_file:
    history = history_file.read()

requirements = [
    'paho-mqtt',
    'pytest-play>=2.0.0',
]

setup_requirements = [
    'pytest-runner',
]

test_requirements = [
    'pytest',
    'mock',
    'pytest-cov',
]

setup(
    name='play_mqtt',
    version='0.0.4',
    description="pytest-play support for MQTT",
    long_description=readme + '\n\n' + history,
    author="Davide Moro",
    author_email='davide.moro@gmail.com',
    url='https://github.com/davidemoro/play_mqtt',
    packages=find_packages(include=['play_mqtt']),
    entry_points={
        'playcommands': [
            'mqtt = play_mqtt.providers:MQTTProvider',
        ],
    },
    include_package_data=True,
    install_requires=requirements,
    license="Apache Software License 2.0",
    zip_safe=False,
    keywords='play_mqtt',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
    test_suite='tests',
    tests_require=test_requirements,
    setup_requires=setup_requirements,
    extras_require={
        'tests': test_requirements,
    },
)
